==> plugin.video.filmsforaction-1.1.1.zip: plugin.video.filmsforaction/README.md <==
Films For Action Videos: XBMC video add-on to watch the Films For Action videos from the FFA web site.

   Copyright (C) 2014 Jose Antonio Montes (jamontes)

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.


Initial release 1.0.0

[![Build Status](https://secure.travis-ci.org/jamontes/plugin.video.filmsforaction.png)](http://travis-ci.org/jamontes/plugin.video.filmsforaction)

This XBMC plugin allows to watch the videos from the Films For Action web site (more than 2500 videos available).

<< Films For Action is a community-powered learning library and alternative news center for people who want to change the world.

At an International Level:
Films For Action uses the power of film to raise awareness of important social, environmental, and media-related issues not covered by the mainstream news. Our goal is to provide citizens with the information and perspectives essential to creating a more just, sustainable, and democratic society.

At the Local Level:
On the ground, our City Chapters are working to create alternative media channels that will inform, connect, and inspire action at a community level.

Our city chapters screen documentaries at independent theaters and other venues regularly throughout the year. With most films we launch an accompanying educational and action-oriented campaign to address the issues presented by the films. Some of our chapters air films on their local public Access TV channel. And all the films we buy we make available for people to borrow from us for free, either to watch themselves or to screen in their own neighborhoods.

Our local city chapter sub-sites offer several tools to connect and inform people through our website, including a calendar of local activist events, a directory of local progressive and radical groups, and a blog for writers to contribute local news and perspectives.

All in all, through the screenings, public access TV, this website, and our Lending Library, our City Chapters aim to provide an information and resource network that will reduce its city's dependence on corporate media, providing more meaningful and reliable ways to stay informed on the issues that matter. >>  (citation: https://www.filmsforaction.org/about/)

To install it simply download the zip file, and then proceed as with any other plugin from XBMC:
 System->Settings->Add-ons->Install from zip file.

Any issues detected can be reported using this forum thread for official support: https://forum.kodi.tv/showthread.php?tid=198524

Enjoy it!

jamontes

==> plugin.video.filmsforaction-1.1.2.zip: plugin.video.filmsforaction/README.md <==
Films For Action Videos: KODI video add-on to watch the Films For Action videos from the FFA web site.

   Copyright (C) 2014 Jose Antonio Montes (jamontes)

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.


Initial release 1.0.0

[![Build status](https://ci.appveyor.com/api/projects/status/b6cc9449bhep93aj/branch/master?svg=true)](https://ci.appveyor.com/project/jamontes/plugin-video-filmsforaction/branch/master)

This KODI add-on allows to watch the videos from the Films For Action web site (more than 2500 videos available).

<< Films For Action is a community-powered learning library and alternative news center for people who want to change the world.

At an International Level:
Films For Action uses the power of film to raise awareness of important social, environmental, and media-related issues not covered by the mainstream news. Our goal is to provide citizens with the information and perspectives essential to creating a more just, sustainable, and democratic society.

At the Local Level:
On the ground, our City Chapters are working to create alternative media channels that will inform, connect, and inspire action at a community level.

Our city chapters screen documentaries at independent theaters and other venues regularly throughout the year. With most films we launch an accompanying educational and action-oriented campaign to address the issues presented by the films. Some of our chapters air films on their local public Access TV channel. And all the films we buy we make available for people to borrow from us for free, either to watch themselves or to screen in their own neighborhoods.

Our local city chapter sub-sites offer several tools to connect and inform people through our website, including a calendar of local activist events, a directory of local progressive and radical groups, and a blog for writers to contribute local news and perspectives.

All in all, through the screenings, public access TV, this website, and our Lending Library, our City Chapters aim to provide an information and resource network that will reduce its city's dependence on corporate media, providing more meaningful and reliable ways to stay informed on the issues that matter. >>  (citation: https://www.filmsforaction.org/about/)

To install it simply download the zip file, and then proceed as with any other plugin from XBMC:
 System->Settings->Add-ons->Install from zip file.

Any issues detected can be reported using this forum thread for official support: https://forum.kodi.tv/showthread.php?tid=198524

Enjoy it!

jamontes
